@@ -13,9 +13,6 @@ import getpass, hashlib, collections
 import unicodedata
 from itertools import compress, product
 
-# Third party modules #
-from six import string_types
-
 # One liners #
 flatter = lambda x: [item for sublist in x for item in sublist]
 
@@ -55,7 +52,8 @@ def sanitize_text(text):
 ################################################################################
 def camel_to_snake(text):
     """
-    Will convert CamelCaseStrings to snake_case_strings.
+    Will convert CamelCaseStrings to snake_case_strings. Examples:
+
     >>> camel_to_snake('CamelCase')
     'camel_case'
     >>> camel_to_snake('CamelCamelCase')
@@ -76,6 +74,8 @@ def camel_to_snake(text):
     'sw_merch'
     >>> camel_to_snake('Odd/Characters')
     'odd_characters'
+    >>> camel_to_snake('With Spaces')
+    'with_spaces'
     """
     # Load #
     result = text
@@ -92,10 +92,13 @@ def camel_to_snake(text):
     # Lower case the rest #
     result = result.lower()
     # Eliminate remaining spaces #
-    result = result.replace(' ', '')
+    result = result.replace(' ', '_')
     # Eliminate quote characters #
     result = result.replace('"', '')
     result = result.replace("'", '')
+    # Eliminate parenthesis #
+    result = result.replace("(", '')
+    result = result.replace(")", '')
     # Eliminate special characters #
     result = result.replace('/', '_')
     # Eliminate double underscore #
@@ -105,11 +108,13 @@ def camel_to_snake(text):
 
 ################################################################################
 def bool_to_unicode(b):
-    """Different possibilities for True: ☑️✔︎✓✅👍✔️
-       Different possibilities for False: ✕✖︎✗✘✖️❌⛔️❎👎🛑🔴"""
+    """
+    Different possibilities for True: ☑️✔︎✓✅👍✔️
+    Different possibilities for False: ✕✖︎✗✘✖️❌⛔️❎👎🛑🔴
+    """
     b = bool(b)
     if b is True:  return u"✅"
-    if b is False: return u"❎"
+    if b is False: return u"🔴"
 
 ###############################################################################
 def access_dict_like_obj(obj, prop, new_value=None):
@@ -299,8 +304,9 @@ def sum_vectors_with_padding(vectors):
 
 ###############################################################################
 def moving_average(interval, windowsize, borders=None):
-    """This is essentially a convolution operation
-     Several option exist for dealing with the border cases.
+    """
+    This is essentially a convolution operation
+    Several option exist for dealing with the border cases.
 
         * None: Here the returned signal will be smaller than the inputted interval.
 
@@ -391,7 +397,7 @@ def split_thousands(s):
     # Check input #
     if s is None: return "0"
     # If it's a string #
-    if isinstance(s, string_types): s = float(s)
+    if isinstance(s, str): s = float(s)
     # If it's a float that should be an int #
     if isinstance(s, float) and s.is_integer(): s = int(s)
     # Use python built-in #
